import moment from "moment";

interface IColumnHeader {
  Header: string;
  accessor: string | ((row: any) => string);
  Cell?: (row: any) => JSX.Element;
}

type Columns = IColumnHeader[];

export const columnsDataConsumer: Columns = [
  {
    Header: "Consumer ID",
    accessor: "id",
  },
  {
    Header: "Contract Account",
    accessor: (row: any) => `${row.attempt?.case?.contract_account || ""}`,
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Meter No",
    accessor: "meter_no",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Meter Reading",
    accessor: "meter_reading",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Cycle Day",
    accessor: "attempt.case.cycle_day.cycle_day",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "IBC",
    accessor: "attempt.case.ibc.area_name",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Contact Person",
    accessor: "contact_person",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Mobile No",
    accessor: "mobile_no",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Paid Amount",
    accessor: "paid_amount",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Category",
    accessor: "category",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Latitude",
    accessor: "latitude",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Longitude",
    accessor: "longitude",
    Cell: ({ value }) => value ?? "N/A",
  },
  {
    Header: "Created By",
    accessor: (row: any) =>
      `${row.created_by?.first_name || ""} ${row.created_by?.last_name || ""
        }`.trim(),
    Cell: ({ value }) => value || "N/A",
  },
  {
    Header: "Created At",
    accessor: "created_at",
    Cell: ({ value }) => {
      if (!value) return "N/A";
      const date = moment(value).format("DD/MM/YYYY, hh:mm A");

      // const hours = date.getHours().toString().padStart(2, "0");
      // const minutes = date.getMinutes().toString().padStart(2, "0");
      // const day = date.getDate().toString().padStart(2, "0");
      // const month = (date.getMonth() + 1).toString().padStart(2, "0"); // Months are 0-based
      // const year = date.getFullYear();

      return date;
    }
  },
  {
    Header: "Remarks",
    accessor: "remarks",
    Cell: ({ value }) => value ?? "N/A",
  },
];
